# 貢獻者公約行為準則

## 我們的承諾

我們作為成員、貢獻者和領導者，承諾讓參與我們社區的每個人，無論年齡、體型、可見或不可見的殘疾、種族、性別特徵、性別認同與表達、經驗水平、教育程度、社會經濟地位、國籍、外貌、種族、宗教、性取向或性別認同，都能享有免於騷擾的體驗。

我們承諾以促進開放、歡迎、多元、包容且健康的社區方式行動與互動。

## 我們的標準

為我們的社區營造積極環境的行為範例包括：

* 對他人展現同理心與善意
* 尊重不同的意見、觀點與經驗
* 給予並優雅接受建設性反饋
* 承擔責任並向受我們錯誤影響的人道歉，從經驗中學習
* 關注的不僅是對我們個人最有利的事，更是對整個社區最有益的事

不可接受行為的例子包括：

* 使用帶有性暗示的語言或圖像，以及任何形式的性關注或挑逗行為  
* 惡意挑釁、侮辱或貶低性言論，以及個人或政治攻擊  
* 公開或私下的騷擾行為  
* 在未經他人明確許可的情況下，公開其私人信息（如實體地址或電子郵件地址）  
* 其他在專業場合中被合理視為不當的行為

## 執行責任

社區領袖有責任釐清並執行我們的可接受行為標準，並會針對任何他們認為不當、威脅性、冒犯性或有害的行為，採取適當且公正的糾正措施。

社區領袖有權且有責任刪除、編輯或拒絕與本行為準則不符的評論、提交、代碼、維基編輯、問題及其他貢獻，並在適當時說明管理決策的原因。

## 範圍

本行為準則適用於所有社區空間，同時也適用於個人正式代表社區於公共場合時。代表我們社區的範例包括使用官方電子郵件地址、透過官方社群媒體帳號發文，或是在線上或線下活動中擔任指定代表。

## 執行

任何濫用、騷擾或其他不可接受的行為實例，均可向負責執行的社區領袖報告，聯繫方式為 `aw@funstory.ai`。
所有投訴將得到及時且公正的審查與調查。

所有社區領袖均有義務尊重事件舉報者的隱私與安全。

## 執行指南

社群領導者將依據這些社群影響指南，來決定他們認為違反此行為準則的任何行動所應承擔的後果：

### 1. 修正

**社群影響**：在社群中使用不當語言或其他被視為不專業或不受歡迎的行為。

**後果**：社群領導者將私下發出書面警告，明確說明違規行為的性質並解釋為何該行為不恰當。可能會要求公開道歉。

### 2. 警告

**社群影響**：單一事件或一系列行為造成的違規。

**後果**：警告並附帶持續行為的後果。在指定時間內不得與相關人員互動，包括主動與執行行為準則的人員接觸。這包括避免在社群空間及外部管道（如社交媒體）上的互動。違反這些條款可能導致暫時或永久封禁。

### 3. 臨時封禁

**社群影響**：嚴重違反社群標準，包括持續的不當行為。

**後果**：在指定時間內暫時禁止與社群進行任何形式的互動或公開交流。在此期間，不得與相關人員進行公開或私下互動，包括未經請求與執行行為準則的人員互動。違反這些條款可能導致永久封禁。

### 4. 永久封禁

**社群影響**：展現出違反社群標準的行為模式，包括持續不當行為、對個人的騷擾，或對特定群體的攻擊與貶抑。

**後果**：永久禁止在社群內進行任何形式的公開互動。

## 歸屬

本行為準則改編自 [貢獻者公約][homepage] 2.0 版，可在 https://www.contributor-covenant.org/version/2/0/code_of_conduct.html 查閱。

社區影響指南的靈感來自 [Mozilla 的行為準則執行階梯](https://github.com/mozilla/diversity)。

[homepage]: https://www.contributor-covenant.org

有關本行為準則的常見問題解答，請參閱 https://www.contributor-covenant.org/faq 的 常見問題。翻譯版本可在 https://www.contributor-covenant.org/translations 取得。

<div align="right"> 
<h6><small>Some content on this page has been translated by GPT and may contain errors.</small></h6>